summaryrefslogtreecommitdiff
path: root/sw/inc/cshtyp.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/inc/cshtyp.hxx')
-rw-r--r--sw/inc/cshtyp.hxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/sw/inc/cshtyp.hxx b/sw/inc/cshtyp.hxx
index 0509b9116ee2..2ba43ffef947 100644
--- a/sw/inc/cshtyp.hxx
+++ b/sw/inc/cshtyp.hxx
@@ -23,7 +23,7 @@
#include "swdllapi.h"
class SwPaM;
-class SwCntntFrm;
+class SwContentFrm;
class SwLayoutFrm;
// Structure for SwPaM. Contains the method-pointers for cursor movement.
@@ -31,13 +31,13 @@ struct SwMoveFnCollection;
typedef SwMoveFnCollection* SwMoveFn;
// Type definition for CrsrShell.
// Direction-parameter for MovePage (initialized in SwCntntFrm).
typedef SwLayoutFrm * (*SwWhichPage)( const SwLayoutFrm * );
-typedef SwCntntFrm * (*SwPosPage)( const SwLayoutFrm * );
+typedef SwContentFrm * (*SwPosPage)( const SwLayoutFrm * );
extern SwWhichPage fnPagePrev, fnPageCurr, fnPageNext;
extern SwPosPage fnPageStart, fnPageEnd;
// Direction-parameter for MovePara (initialized in SwCntntFrm).
typedef SwMoveFnCollection* SwPosPara;
typedef bool (*SwWhichPara)( SwPaM&, SwPosPara );
extern SwWhichPara fnParaPrev, fnParaCurr, fnParaNext;
@@ -57,7 +57,7 @@ extern SwPosTable fnTableStart, fnTableEnd;
// Direction-parameter for MoveColumn
typedef SwLayoutFrm * (*SwWhichColumn)( const SwLayoutFrm * );
-typedef SwCntntFrm * (*SwPosColumn)( const SwLayoutFrm * );
+typedef SwContentFrm * (*SwPosColumn)( const SwLayoutFrm * );
extern SwWhichColumn fnColumnPrev, fnColumnCurr, fnColumnNext;
extern SwPosColumn fnColumnStart, fnColumnEnd;
@@ -31,13 +31,13 @@ struct SwMoveFnCollection;
typedef SwMoveFnCollection* SwMoveFn;
// Type definition for CrsrShell.
-// Direction-parameter for MovePage (initialized in SwCntntFrm).
+// Direction-parameter for MovePage (initialized in SwContentFrm).
typedef SwLayoutFrm * (*SwWhichPage)( const SwLayoutFrm * );
@@ -31,13 +31,13 @@ struct SwMoveFnCollection;
extern SwWhichPage fnPagePrev, fnPageCurr, fnPageNext;
extern SwPosPage fnPageStart, fnPageEnd;
-// Direction-parameter for MovePara (initialized in SwCntntFrm).
+// Direction-parameter for MovePara (initialized in SwContentFrm).
typedef SwMoveFnCollection* SwPosPara;
typedef bool (*SwWhichPara)( SwPaM&, SwPosPara );